<?php
/*-------------------------------------------------------+
| Filename: core.php
| Author: Mateusz Sieprawski - http://duner.pl/
+--------------------------------------------------------*/
if(!defined('IN_FUSION')) die('Access Denied');



/**
 * User_location Class
 * 
 * @author   Mateusz Sieprawski
 * @link     http://duner.pl/
 * @created  21.04.2012 
 */
class User_location {
    
    public $user_x = 0;
    public $user_y = 0;
    public $locale_file = 'English.php';
    
    protected $_installed = FALSE;
    protected $_settings = array();
    
    private $_infusion_version = '1.2';
        
    
    /**
     * __contruct
     * 
     * @return  void
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    public function __construct() {
        require_once INCLUDES."infusions_include.php";
        
        // define infusion constants
        $this->_define_constants();
        
        // set locale file
        $this->_set_locale();
        
        // get infusion settings
        $this->get_infusion_settings(TRUE);
        
        // install or uninstall infusion
        $this->_install_infusion();
        
        // install or uninstall infusion user fields
        $this->_set_userfield();
        
        // get user location coords
        $this->_get_user_location();
    }
    
    
    
    /**
     * save_infusion_settings
     * 
     * @return  bool
     * @param   array
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    public function save_infusion_settings($data) {
        
        // for each key of array set setting
        foreach($data as $key => $val) {
            set_setting($key, $val, INF_FOLDER);
        }
        
        // update user_goole user field
        return $this->_update_userfield($data['user_location_registration'], $data['user_location_required']);
    }
    
    
    
    /**
     * get_infusion_settings
     * 
     * @return  array
     * @param   bool
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    public function get_infusion_settings($refresh = FALSE) {
        
        // refresh settings
        if($refresh == TRUE) {
            $this->_settings = get_settings(INF_FOLDER);
        }
        
        return $this->_settings;
    }
    
    
    
    /**
     * get_center_coords
     * 
     * @return  object
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    public function get_center_coords() {
        $result = array('x' => 0, 'y' => 0);
        
        // get center coords
        if(isSet($this->_settings['user_location_center']) && $this->valid_coords($this->_settings['user_location_center']) == TRUE) {
            $explode = explode(',', $this->_settings['user_location_center']);
            if(isSet($explode[0]) && isSet($explode[1])) {
                $result['x'] = $explode[0];
                $result['y'] = str_replace(' ', '', $explode[1]);
                $result['y'] = str_replace('%20', '', $result['y']);
            }
        }
        
        return $result;
    }
    
    
    
    /**
     * valid_coords
     * 
     * @return  bool
     * @param   string
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    public function valid_coords($coords) {
        
        // check length of coords
        if(strlen($coords) >= 10 OR strlen($coords) <= 24) {
            
            // check if coords contains ',' separator
            if(strpos($coords, ',') !== FALSE) {
                $dots = explode(',', $coords);
                
                if(isSet($dots[0])) {
                    
                    // check if first coord contains '.'
                    if(strpos($dots[0], '.') !== FALSE) {
                        if(isSet($dots[1])) {
                            
                            // check if second coord contains '.'
                            if(strpos($dots[1], '.') !== FALSE) {
                                return TRUE;
                            }
                        }
                    }
                }
            }
        }
        
        return FALSE;
    }
    
    
    
    /**
     * settings
     * 
     * @return  array
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    public function settings() {
        return $this->_settings;
    }
    
    
    
    /**
     * is_installed
     * 
     * @return  bool
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    public function is_installed() {
        return $this->_installed;
    }
    
    
    
    /**
     * _set_userfield
     * 
     * @return  void
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    private function _set_userfield() {
        
        // if infusion is installed
        if($this->_installed == TRUE) {
            
            // insert into user fields table new rows
            $query = dbquery("SELECT field_id FROM `".DB_USER_FIELDS."` WHERE field_name='user_google' LIMIT 1");
            if(dbrows($query) == 0) {
                $order = dbresult(dbquery("SELECT MAX(field_order) FROM ".DB_USER_FIELDS." WHERE field_cat='2'"), 0) + 1;
                dbquery("INSERT INTO `".DB_USER_FIELDS."` VALUES (NULL, 'user_google', '2', '1', '0', '1', '$order')");
            }
            
            // insert into user fields table new rows
            $query = dbquery("SELECT field_id FROM `".DB_USER_FIELDS."` WHERE field_name='user_google-profile' LIMIT 1");
            if(dbrows($query) == 0) {
                $order = dbresult(dbquery("SELECT MAX(field_order) FROM ".DB_USER_FIELDS." WHERE field_cat='2'"), 0) + 1;
                dbquery("INSERT INTO `".DB_USER_FIELDS."` VALUES (NULL, 'user_google-profile', '2', '0', '0', '0', '$order')");
            }
        } else {
            
            // insert into user fields table new rows
            $query = dbquery("SELECT field_id, field_cat, field_order FROM `".DB_USER_FIELDS."` WHERE field_name='user_google' LIMIT 1");
            if(dbrows($query) == 1) {
                $data = dbarray($query);
                
                dbquery("UPDATE `".DB_USER_FIELDS."` SET field_order=field_order-1 WHERE field_cat='".$data['field_cat']."' AND field_order>'".$data['field_order']."'");
		dbquery("DELETE FROM `".DB_USER_FIELDS."` WHERE field_id='".$data['field_id']."'");
            }
            
            // insert into user fields table new rows
            $query = dbquery("SELECT field_id, field_cat, field_order FROM `".DB_USER_FIELDS."` WHERE field_name='user_google-profile' LIMIT 1");
            if(dbrows($query) == 1) {
                $data = dbarray($query);
                
                dbquery("UPDATE `".DB_USER_FIELDS."` SET field_order=field_order-1 WHERE field_cat='".$data['field_cat']."' AND field_order>'".$data['field_order']."'");
		dbquery("DELETE FROM `".DB_USER_FIELDS."` WHERE field_id='".$data['field_id']."'");
            }
        }
    }
    
    
    
    /**
     * _install_infusion
     * 
     * @return  void
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    private function _install_infusion() {
        
        // check if infusion is installed
        $query = dbquery("SELECT inf_id FROM `".DB_INFUSIONS."` WHERE inf_folder='".INF_FOLDER."'");
        if(dbrows($query) > 0) {
            $data = dbarray(dbquery("SELECT * FROM `".DB_USERS."` LIMIT 1"));

            // add new column to users table
            if(!array_key_exists('user_google', $data)) {
                dbquery("ALTER TABLE `".DB_USERS."` ADD user_google VARCHAR(100) DEFAULT ''");
            }
            
            // add new column to users table
            if(!array_key_exists('user_google_profile', $data)) {
                dbquery("ALTER TABLE `".DB_USERS."` ADD user_google_profile TINYINT(1) NOT NULL DEFAULT '0'");
            }
            
            $this->_installed = TRUE;
        } else {
            $data = dbarray(dbquery("SELECT * FROM `".DB_USERS."` LIMIT 1"));

            // delete column from users table
            if(array_key_exists('user_google', $data)) {
                dbquery("ALTER TABLE `".DB_USERS."` DROP COLUMN user_google");
            }
            
            // delete column from users table
            if(array_key_exists('user_google', $data)) {
                dbquery("ALTER TABLE `".DB_USERS."` DROP COLUMN user_google_profile");
            }
            
            // delete all infusion settings from settings_inf table
            if(is_array($this->_settings) && !empty($this->_settings)) {
                if(dbcount("(settings_inf)", DB_SETTINGS_INF, "settings_inf='".INF_FOLDER."'") > 0) {
                    dbquery("DELETE FROM `".DB_SETTINGS_INF."` WHERE settings_inf='".INF_FOLDER."'");
                }
            }
        }
    }
    
    
    
    /**
     * _define_constants
     * 
     * @return  void
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    private function _define_constants() {
        
        // define infusion folder
        if(!defined('INF_FOLDER')) {
            define('INF_FOLDER', 'duner_user_location');
        }
        
        // define infusion version
        if(!defined('INF_VERSION')) {
            define('INF_VERSION', $this->_infusion_version);
        }
    }
    
    
    
    /**
     * _get_user_location
     * 
     * @return  void
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    private function _get_user_location() {
        global $userdata;
        
        // if infusion is installed
        if($this->_installed == TRUE) {
            
            // is it profile page?
            if(FUSION_SELF == "profile.php") {
                
                // get user data
                if(isSet($_GET['lookup']) && isnum($_GET['lookup'])) {
                    $user_data = dbarray(dbquery("SELECT user_google FROM `".DB_USERS."` WHERE user_id='".$_GET['lookup']."' LIMIT 1"));
                    
                    // if is set user location
                    if(array_key_exists('user_google', $user_data) && $user_data['user_google'] != NULL) {
                        $location = explode(', ', $user_data['user_google']);

                        $this->user_y = $location[0];
                        $this->user_x = $location[1];
                    }
                }
                
            } else {
                
                // if is set user location
                if(array_key_exists('user_google', $userdata) && $userdata['user_google'] != NULL) {
                    $location = explode(', ', $userdata['user_google']);

                    $this->user_y = $location[0];
                    $this->user_x = $location[1];
                }
            }
        }
    }
    
    
    
    /**
     * _set_registration
     * 
     * @return  bool
     * @param   integer, integer
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    private function _update_userfield($registration, $required) {
        
        // if infusion is installed
        if($this->_installed == TRUE) {
            
            // check if user field is installed
            $query = dbquery("SELECT field_id FROM `".DB_USER_FIELDS."` WHERE field_name='user_google' LIMIT 1");
            if(dbrows($query) == 1) {
                $data = dbarray($query);
                
                // change user field settings
                $result_1 = dbquery("UPDATE `".DB_USER_FIELDS."` SET field_registration='$registration' WHERE field_id='".$data['field_id']."'");
                $result_2 = dbquery("UPDATE `".DB_USER_FIELDS."` SET field_required='$required' WHERE field_id='".$data['field_id']."'");
                
                if($result_1 != FALSE && $result_2 != FALSE) {
                    return TRUE;
                }
            }
            
        }
        
        return FALSE;
    }
    
    
    
    /**
     * _include_locale
     * 
     * @return  void
     * @author  Mateusz Sieprawski
     * @link    http://duner.pl/
     */
    private function _set_locale() {
        global $settings;
        
        // check if locale file exists
        if(file_exists(INFUSIONS.INF_FOLDER."/locale/".$settings['locale'].".php")) {
            $this->locale_file = $settings['locale'].".php";
        }
    }
    
}